@@ -196,10 +196,10 @@ class mstr_global:
             , "subtype": str(obj_d.get('subtype'))
             , "owner_id": str(obj_d["owner"].get('id'))
             , "owner_name": str(obj_d["owner"].get('name'))
-            , "date_modified": str(obj_d["dateModified"])
-            , "date_created": str(obj_d["dateCreated"])
+            , "date_modified": str(obj_d["owner"].get('dateModified'))
+            , "date_created": str(obj_d["owner"].get('dateCreated'))
                      }
-        #print(obj_row_d["date_created"] )
+        # print("project: " + proj_g + "object: " + str(obj_d.get('id')) )
         return obj_row_d
 
     def bld_mstr_obj_guid(self, obj_md_id=None):
